/*
 * This file is generated by objective.metadata
 *
 * Last update: Wed Jan 16 13:10:52 2013
 */
#import <IMServicePlugIn/IMServicePlugInFileTransferSessionSupport.h>

static void __attribute__((__used__)) use_protocols(void)
{
    PyObject* p __attribute__((__unused__));
    p = PyObjC_IdToPython(@protocol(IMServiceApplication));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServiceApplicationChatRoomSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServiceApplicationFileTransferSessionSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServiceApplicationGroupListAuthorizationSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServiceApplicationGroupListSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServiceApplicationInstantMessagingSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugIn));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugInChatRoomSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugInFileTransferSessionSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugInGroupListAuthorizationSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugInGroupListEditingSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugInGroupListHandlePictureSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugInGroupListOrderingSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugInGroupListSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugInInstantMessagingSupport));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(IMServicePlugInPresenceSupport));
    Py_XDECREF(p);
}
